@@ -2,5 +2,6 @@
 
 from eva.core.loggers.log.image import log_image
 from eva.core.loggers.log.parameters import log_parameters
+from eva.core.loggers.log.table import log_table
 
-__all__ = ["log_image", "log_parameters"]
+__all__ = ["log_image", "log_parameters", "log_table"]
