@@ -3,5 +3,6 @@
 from eva.core.utils.clone import clone
 from eva.core.utils.memory import to_cpu
 from eva.core.utils.operations import numeric_sort
+from eva.core.utils.paths import home_dir
 
-__all__ = ["clone", "to_cpu", "numeric_sort"]
+__all__ = ["clone", "to_cpu", "numeric_sort", "home_dir"]
