@@ -22,7 +22,6 @@ from eva.vision.data.datasets.segmentation import (
     LiTS17,
     MoNuSAC,
     MSDTask7Pancreas,
-    TotalSegmentator2D,
 )
 from eva.vision.data.datasets.vision import VisionDataset
 from eva.vision.data.datasets.wsi import MultiWsiDataset, WsiDataset
@@ -40,7 +39,6 @@ __all__ = [
     "PANDASmall",
     "Camelyon16",
     "PatchCamelyon",
-    "TotalSegmentator2D",
     "UniToPatho",
     "WsiClassificationDataset",
     "CoNSeP",
