@@ -7,7 +7,6 @@ from eva.vision.data.datasets.segmentation.embeddings import EmbeddingsSegmentat
 from eva.vision.data.datasets.segmentation.lits17 import LiTS17
 from eva.vision.data.datasets.segmentation.monusac import MoNuSAC
 from eva.vision.data.datasets.segmentation.msd_task7_pancreas import MSDTask7Pancreas
-from eva.vision.data.datasets.segmentation.total_segmentator_2d import TotalSegmentator2D
 
 __all__ = [
     "BCSS",
@@ -17,5 +16,4 @@ __all__ = [
     "LiTS17",
     "MSDTask7Pancreas",
     "MoNuSAC",
-    "TotalSegmentator2D",
 ]
