@@ -1,7 +1,8 @@
 """Transforms for spatial operations."""
 
 from eva.vision.data.transforms.spatial.flip import RandFlip
+from eva.vision.data.transforms.spatial.resize import Resize
 from eva.vision.data.transforms.spatial.rotate import RandRotate90
 from eva.vision.data.transforms.spatial.spacing import Spacing
 
-__all__ = ["Spacing", "RandFlip", "RandRotate90"]
+__all__ = ["Spacing", "RandFlip", "RandRotate90", "Resize"]
